@@ -36,9 +36,10 @@ Most users will want to look at TestWithFixtures and Fixture, to start with.
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 3, 9, 'final', 0)
+__version__ = (0, 3, 10, 'final', 0)
 
 __all__ = [
+    'DetailStream',
     'EnvironmentVariable',
     'EnvironmentVariableFixture',
     'FakeLogger',
@@ -54,6 +55,7 @@ __all__ = [
     'PythonPackage',
     'PythonPathEntry',
     'TempDir',
+    'TempHomeDir',
     'TestWithFixtures',
     'Timeout',
     'TimeoutException',
@@ -66,6 +68,7 @@ from fixtures.fixture import (
     MethodFixture,
     )
 from fixtures._fixtures import (
+    DetailStream,
     EnvironmentVariable,
     EnvironmentVariableFixture,
     FakeLogger,
