@@ -17,6 +17,7 @@
 """Included fixtures."""
 
 __all__ = [
+    'DetailStream',
     'EnvironmentVariable',
     'EnvironmentVariableFixture',
     'FakeLogger',
@@ -29,11 +30,13 @@ __all__ = [
     'PythonPackage',
     'PythonPathEntry',
     'TempDir',
+    'TempHomeDir',
     'Timeout',
     'TimeoutException',
     ]
 
 
+from fixtures._fixtures.detailstream import DetailStream
 from fixtures._fixtures.environ import (
     EnvironmentVariable,
     EnvironmentVariableFixture,
